@@ -37,11 +37,13 @@ from ..utils.utils import ModuleInfo, PageInfo, run
 
 logger = logging.getLogger(__name__)
 
-SCREENFETCH_PATH = os.path.join(ROOT_DIR, "screenfetch")
+SCREENFETCH_PATH = os.path.join(ROOT_DIR, "vendored", "screenfetch")
 UWUFETCH_PATH = shutil.which("uwufetch")
 ENV = {
     "USER": NAME,
-    "SHELL": f"python{sys.version.split(' ', maxsplit=1)[0]}",
+    "SHELL": (  # noqa: B950  # pylint: disable=line-too-long, useless-suppression
+        f"{sys.implementation.name}{'.'.join(str(_) for _ in sys.version_info[:3])}"
+    ),
 }
 
 
@@ -97,16 +99,17 @@ class HostInfo(HTMLRequestHandler):
         if head:
             return
 
-        if not self.SCREENFETCH_CACHE.value:
-            self.SCREENFETCH_CACHE.value = minify_ansi_art(
-                (await run(SCREENFETCH_PATH, "-L"))[1]
-            )
+        logo = self.SCREENFETCH_CACHE.value
+
+        if not logo:
+            logo = minify_ansi_art((await run(SCREENFETCH_PATH, "-L"))[1])
+            self.SCREENFETCH_CACHE.value = logo
 
         await self.render(
             "ansi2html.html",
             ansi=[
-                self.SCREENFETCH_CACHE.value.decode("utf-8"),
-                (await run(SCREENFETCH_PATH, "-n", env=ENV))[1].decode("utf-8"),
+                logo.decode("UTF-8"),
+                (await run(SCREENFETCH_PATH, "-n", env=ENV))[1].decode("UTF-8"),
             ],
             powered_by="https://github.com/KittyKatt/screenFetch",
             powered_by_name="screenFetch",
@@ -150,7 +153,7 @@ class UwUHostInfo(HTMLRequestHandler):
         if head:
             return
 
-        uwufetch = uwufetch_bytes.decode("utf-8").split("\n\n")
+        uwufetch = uwufetch_bytes.decode("UTF-8").split("\n\n")
         await self.render(
             "ansi2html.html",
             ansi=uwufetch,
