@@ -28,7 +28,7 @@ import types
 from asyncio import AbstractEventLoop
 from asyncio.runners import _cancel_all_tasks  # type: ignore[attr-defined]
 from base64 import b64encode
-from collections.abc import Callable, Coroutine
+from collections.abc import Callable, Coroutine, Iterable
 from configparser import ConfigParser
 from hashlib import sha256
 from multiprocessing import process
@@ -50,6 +50,7 @@ from redis.asyncio import (
     SSLConnection,
     UnixDomainSocketConnection,
 )
+from setproctitle import setproctitle
 from tornado.httpserver import HTTPServer
 from tornado.log import LogFormatter
 from tornado.web import Application, RedirectHandler
@@ -65,7 +66,7 @@ from . import (
     VERSION,
 )
 from .contact.contact import apply_contact_stuff_to_app
-from .quotes import AUTHORS_CACHE, QUOTES_CACHE, WRONG_QUOTES_CACHE
+from .quotes.utils import AUTHORS_CACHE, QUOTES_CACHE, WRONG_QUOTES_CACHE
 from .utils import static_file_handling
 from .utils.base_request_handler import BaseRequestHandler
 from .utils.logging import WebhookFormatter, WebhookHandler
@@ -81,21 +82,13 @@ from .utils.utils import (
 )
 
 IGNORED_MODULES = {
-    "backdoor.client",
     "patches.*",
-    "quotes.quotes_image",
-    "quotes.share_page",
     "static.*",
-    "swapped_words.sw_config_file",
     "templates.*",
-    "utils.base_request_handler",
-    "utils.logging",
-    "utils.static_file_handling",
-    "utils.utils",
-}
+} | (set() if sys.flags.dev_mode else {"example.*"})
 
 CONFIG = ConfigParser(interpolation=None)
-CONFIG.read("config.ini", encoding="utf-8")
+CONFIG.read("config.ini", encoding="UTF-8")
 
 logger = logging.getLogger(__name__)
 
@@ -117,6 +110,19 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
         ):
             continue
 
+        _module_infos = get_module_infos_from_module(
+            potential_module, errors, ignore_not_found=True
+        )
+        if _module_infos:
+            module_infos.extend(_module_infos)
+            loaded_modules.append(potential_module)
+            logger.info(
+                "Found module_infos in %s.__init__.py, "
+                "do not search in other files in the module.",
+                potential_module,
+            )
+            continue
+
         for potential_file in os.listdir(os.path.join(DIR, potential_module)):
             module_name = f"{potential_module}.{potential_file[:-3]}"
             if (
@@ -125,44 +131,10 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
                 or potential_file.startswith("_")
             ):
                 continue
-
-            import_timer = Timer()
-            module = importlib.import_module(
-                f".{module_name}",
-                package="an_website",
-            )
-
-            if "get_module_info" not in dir(module):
-                errors.append(
-                    f"{os.path.join(DIR, potential_module, potential_file)} "
-                    "has no 'get_module_info' method. Please add the method "
-                    f"or add '{potential_module}.*' or '{module_name}' to "
-                    "IGNORED_MODULES."
-                )
-                continue
-
-            if isinstance(
-                module_info := module.get_module_info(),
-                ModuleInfo,
-            ):
-                module_infos.append(module_info)
+            _module_infos = get_module_infos_from_module(module_name, errors)
+            if _module_infos:
+                module_infos.extend(_module_infos)
                 loaded_modules.append(module_name)
-                if import_timer.stop() > 0.1:
-                    logger.warning(
-                        "Import of %s took %ss. "
-                        "That's affecting the startup time.",
-                        module_name,
-                        import_timer.execution_time,
-                    )
-                continue
-
-            errors.append(
-                "'get_module_info' in "
-                f"{os.path.join(DIR, potential_module, potential_file)} "
-                "does not return ModuleInfo. Please fix the returned value "
-                f"or add '{potential_module}.*' or '{module_name}' to "
-                "IGNORED_MODULES."
-            )
 
     if len(errors) > 0:
         if sys.flags.dev_mode:
@@ -189,6 +161,76 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
     return tuple(module_infos)
 
 
+def get_module_infos_from_module(
+    module_name: str,
+    errors: list[str],  # gets modified
+    ignore_not_found: bool = False,
+) -> None | list[ModuleInfo]:
+    """Get the module infos based on a module."""
+    import_timer = Timer()
+    module = importlib.import_module(
+        f".{module_name}",
+        package="an_website",
+    )
+    if import_timer.stop() > 0.1:
+        logger.warning(
+            "Import of %s took %ss. That's affecting the startup time.",
+            module_name,
+            import_timer.execution_time,
+        )
+
+    module_infos: list[ModuleInfo] = []
+
+    has_get_module_info = "get_module_info" in dir(module)
+    has_get_module_infos = "get_module_infos" in dir(module)
+
+    if not (has_get_module_info or has_get_module_infos):
+        if ignore_not_found:
+            return None
+        errors.append(
+            f"{module_name} has no 'get_module_info' and no 'get_module_infos' "
+            "method. Please add at least one of the methods or add "
+            f"'{module_name.rsplit('.', 1)[0]}.*' or '{module_name}' to "
+            "IGNORED_MODULES."
+        )
+        return None
+
+    if has_get_module_info and isinstance(
+        module_info := module.get_module_info(),
+        ModuleInfo,
+    ):
+        module_infos.append(module_info)
+    elif has_get_module_info:
+        errors.append(
+            f"'get_module_info' in {module_name} does not return ModuleInfo. "
+            "Please fix the returned value."
+        )
+
+    if not has_get_module_infos:
+        return module_infos or None
+
+    _module_infos = module.get_module_infos()
+
+    if not isinstance(_module_infos, Iterable):
+        errors.append(
+            f"'get_module_infos' in {module_name} does not return an Iterable. "
+            "Please fix the returned value."
+        )
+        return module_infos or None
+
+    for _module_info in _module_infos:
+        if isinstance(_module_info, ModuleInfo):
+            module_infos.append(_module_info)
+        else:
+            errors.append(
+                f"'get_module_infos' in {module_name} did return an Iterable "
+                f"with an element of type {type(_module_info)}. "
+                "Please fix the returned value."
+            )
+
+    return module_infos or None
+
+
 def sort_module_infos(module_infos: list[ModuleInfo]) -> None:
     """Sort a list of module info and move the main page to the top."""
     # sort it so the order makes sense
@@ -294,7 +336,6 @@ def make_app(config: ConfigParser) -> str | Application:
         ),
         websocket_ping_interval=10,
         # Template settings
-        autoescape="xhtml_escape",
         template_path=TEMPLATES_DIR,
         template_whitespace="oneline",
     )
@@ -388,16 +429,10 @@ def get_ssl_context(  # pragma: no cover
 
 def setup_logging(  # pragma: no cover
     config: ConfigParser,
-    loop: None | AbstractEventLoop = None,
-    *,
     force: bool = False,
 ) -> None:
     """Setup logging."""  # noqa: D401
     root_logger = logging.getLogger()
-    debug = config.getboolean("LOGGING", "DEBUG", fallback=sys.flags.dev_mode)
-    default_logging_format_no_color = regex.sub(
-        r"%\((end_)?color\)s", "", LogFormatter.DEFAULT_FORMAT
-    )
 
     if root_logger.handlers:
         if not force:
@@ -406,72 +441,83 @@ def setup_logging(  # pragma: no cover
             root_logger.removeHandler(handler)
             handler.close()
 
+    debug = config.getboolean("LOGGING", "DEBUG", fallback=sys.flags.dev_mode)
+
     logging.captureWarnings(True)
+
     root_logger.setLevel(logging.DEBUG if debug else logging.INFO)
     logging.getLogger("tornado.curl_httpclient").setLevel(logging.INFO)
     logging.getLogger("elasticsearch").setLevel(logging.INFO)
 
     stream_handler = logging.StreamHandler()
-    stream_handler.setFormatter(
-        logging.Formatter(
-            default_logging_format_no_color,
-            LogFormatter.DEFAULT_DATE_FORMAT,
-        )
-        if sys.flags.dev_mode
-        else LogFormatter()
-    )
+    if sys.flags.dev_mode:
+        spam = regex.sub(r"%\((end_)?color\)s", "", LogFormatter.DEFAULT_FORMAT)
+        formatter = logging.Formatter(spam, LogFormatter.DEFAULT_DATE_FORMAT)
+    else:
+        formatter = LogFormatter()
+    stream_handler.setFormatter(formatter)
     root_logger.addHandler(stream_handler)
 
     if path := config.get("LOGGING", "PATH", fallback=None):
         os.makedirs(path, 0o755, True)
         file_handler = logging.handlers.TimedRotatingFileHandler(
             os.path.join(path, f"{NAME}.log"),
-            "midnight",
-            backupCount=7,
+            encoding="UTF-8",
+            when="midnight",
+            backupCount=30,
             utc=True,
         )
         file_handler.setFormatter(StdlibFormatter())
         root_logger.addHandler(file_handler)
 
-    if not loop:
+
+def setup_webhook_logging(  # pragma: no cover
+    config: ConfigParser,
+    loop: AbstractEventLoop,
+) -> None:
+    """Setup WebHook logging."""  # noqa: D401
+    if not (webhook_url := config.get("LOGGING", "WEBHOOK_URL", fallback=None)):
         return
 
-    if webhook_url := config.get("LOGGING", "WEBHOOK_URL", fallback=None):
-        webhook_content_type = config.get(
+    spam = regex.sub(r"%\((end_)?color\)s", "", LogFormatter.DEFAULT_FORMAT)
+
+    root_logger = logging.getLogger()
+
+    webhook_content_type = config.get(
+        "LOGGING",
+        "WEBHOOK_CONTENT_TYPE",
+        fallback="application/json",
+    )
+    webhook_handler = WebhookHandler(
+        logging.ERROR,
+        loop=loop,
+        url=webhook_url,
+        content_type=webhook_content_type,
+    )
+    formatter = WebhookFormatter(
+        config.get(
             "LOGGING",
-            "WEBHOOK_CONTENT_TYPE",
-            fallback="application/json",
-        )
-        webhook_handler = WebhookHandler(
-            logging.ERROR,
-            loop=loop,
-            url=webhook_url,
-            content_type=webhook_content_type,
-        )
-        formatter = WebhookFormatter(
-            config.get(
-                "LOGGING",
-                "WEBHOOK_BODY_FORMAT",
-                fallback='{"text":"' + default_logging_format_no_color + '"}',
-            ),
-            config.get(
-                "LOGGING",
-                "WEBHOOK_TIMESTAMP_FORMAT",
-                fallback=None,
-            ),
-        )
-        formatter.timezone = (
-            ZoneInfo(config.get("LOGGING", "WEBHOOK_TIMESTAMP_TIMEZONE"))
-            if config.has_option("LOGGING", "WEBHOOK_TIMESTAMP_TIMEZONE")
-            else None
-        )
-        formatter.escape_message = config.getboolean(
+            "WEBHOOK_BODY_FORMAT",
+            fallback='{"text":"' + spam + '"}',
+        ),
+        config.get(
             "LOGGING",
-            "WEBHOOK_ESCAPE_MESSAGE",
-            fallback=True,
-        )
-        webhook_handler.setFormatter(formatter)
-        root_logger.addHandler(webhook_handler)
+            "WEBHOOK_TIMESTAMP_FORMAT",
+            fallback=None,
+        ),
+    )
+    formatter.timezone = (
+        ZoneInfo(config.get("LOGGING", "WEBHOOK_TIMESTAMP_TIMEZONE"))
+        if config.has_option("LOGGING", "WEBHOOK_TIMESTAMP_TIMEZONE")
+        else None
+    )
+    formatter.escape_message = config.getboolean(
+        "LOGGING",
+        "WEBHOOK_ESCAPE_MESSAGE",
+        fallback=True,
+    )
+    webhook_handler.setFormatter(formatter)
+    root_logger.addHandler(webhook_handler)
 
 
 def setup_apm(app: Application) -> None:  # pragma: no cover
@@ -522,9 +568,9 @@ def setup_apm(app: Application) -> None:  # pragma: no cover
     )
     app.settings["ELASTIC_APM"]["INLINE_SCRIPT_HASH"] = b64encode(
         sha256(
-            app.settings["ELASTIC_APM"]["INLINE_SCRIPT"].encode("ascii")
+            app.settings["ELASTIC_APM"]["INLINE_SCRIPT"].encode("ASCII")
         ).digest()
-    ).decode("ascii")
+    ).decode("ASCII")
     app.settings["ELASTIC_APM"]["CLIENT"] = ElasticAPM(app).client
 
 
@@ -607,10 +653,16 @@ async def check_elasticsearch(app: Application) -> None:  # pragma: no cover
             logger.exception("Connecting to Elasticsearch failed")
         else:
             if not EVENT_ELASTICSEARCH.is_set():
-                await setup_elasticsearch_configs(
-                    es, app.settings["ELASTICSEARCH_PREFIX"]
-                )
-            EVENT_ELASTICSEARCH.set()
+                try:
+                    await setup_elasticsearch_configs(
+                        es, app.settings["ELASTICSEARCH_PREFIX"]
+                    )
+                except Exception:  # pylint: disable=broad-except
+                    logger.exception(
+                        "An exception occured while configuring Elasticsearch"
+                    )
+                else:
+                    EVENT_ELASTICSEARCH.set()
         await asyncio.sleep(20)
 
 
@@ -643,10 +695,12 @@ async def setup_elasticsearch_configs(  # noqa: C901
                 continue
 
             body = orjson.loads(
-                path.read_bytes().replace(b"{prefix}", prefix.encode("ascii"))
+                path.read_bytes().replace(b"{prefix}", prefix.encode("ASCII"))
             )
 
-            name = f"{prefix}-{str(path.relative_to(base_path))[:-5].replace('/', '-')}"
+            name = (
+                f"{prefix}-{str(path.relative_to(base_path))[:-5].replace('/', '-')}"
+            )
 
             try:
                 if what == "ingest_pipelines":
@@ -757,7 +811,7 @@ def signal_handler(  # noqa: D103  # pragma: no cover
     # pylint: disable=unused-argument, missing-function-docstring
     if signalnum in {signal.SIGINT, signal.SIGTERM}:
         EVENT_SHUTDOWN.set()
-    if hasattr(signal, "SIGHUP") and signalnum == signal.SIGHUP:
+    if signalnum == getattr(signal, "SIGHUP", None):
         EVENT_SHUTDOWN.set()
 
 
@@ -765,6 +819,8 @@ def install_signal_handler() -> None:  # pragma: no cover
     """Install the signal handler."""
     signal.signal(signal.SIGINT, signal_handler)
     signal.signal(signal.SIGTERM, signal_handler)
+    if hasattr(signal, "SIGHUP"):
+        signal.signal(signal.SIGHUP, signal_handler)
 
 
 def main() -> None | int | str:  # noqa: C901  # pragma: no cover
@@ -775,23 +831,20 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
     """
     # pylint: disable=too-complex, too-many-branches
     # pylint: disable=too-many-locals, too-many-statements
-
+    setproctitle(NAME)
     install_signal_handler()
-
-    loop = asyncio.get_event_loop_policy().get_event_loop()
-
-    setup_logging(CONFIG, loop)
+    setup_logging(CONFIG)
 
     logger.info("Starting %s %s", NAME, VERSION)
 
     if platform.system() == "Windows":
         logger.warning(
-            "Please note that running %s on Windows is not officially supported",
-            NAME,
+            "Please note that running %s on Windows is not officially"
+            " supported",
+            NAME.removesuffix("-dev"),
         )
 
     ignore_modules(CONFIG)
-
     app = make_app(CONFIG)
     if isinstance(app, str):
         return app
@@ -849,6 +902,7 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
     )
 
     if processes > 0:
+        setproctitle(f"{NAME} - Master")
         tornado.process.fork_processes(processes)
         # yeet all children (there should be none, but do it regardless, just in case)
         process._children.clear()  # type: ignore[attr-defined]  # pylint: disable=protected-access  # noqa: B950
@@ -859,18 +913,25 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
 
     task_id = tornado.process.task_id()
 
-    if unix_socket_path and task_id is not None:
-        sockets.append(
-            tornado.netutil.bind_unix_socket(
-                os.path.join(unix_socket_path, f"{NAME}.{task_id}.sock")
+    if task_id is not None:
+        setproctitle(f"{NAME} - Worker {task_id}")
+        if unix_socket_path:
+            sockets.append(
+                tornado.netutil.bind_unix_socket(
+                    os.path.join(unix_socket_path, f"{NAME}.{task_id}.sock")
+                )
             )
-        )
+
+    # get loop after forking
+    loop = asyncio.get_event_loop_policy().get_event_loop()
 
     _ = asyncio.get_event_loop
     asyncio.get_event_loop = lambda: loop
     server.add_sockets(sockets)
     asyncio.get_event_loop = _
 
+    setup_webhook_logging(CONFIG, loop)
+
     # pylint: disable=import-outside-toplevel, unused-variable
 
     wait_for_shutdown_task = loop.create_task(wait_for_shutdown())  # noqa: F841
@@ -881,7 +942,7 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
     if CONFIG.getboolean("REDIS", "ENABLED", fallback=False):
         check_redis_task = loop.create_task(check_redis(app))  # noqa: F841
 
-    from .quotes import update_cache_periodically
+    from .quotes.utils import update_cache_periodically
 
     if not task_id:
         quotes_cache_update_task = loop.create_task(  # noqa: F841
