@@ -22,20 +22,21 @@ import contextlib
 import http.client
 import json as stdlib_json  # pylint: disable=preferred-module
 import os
-import sys
+import threading
 from collections.abc import Callable
 from pathlib import Path
 from typing import Any
 
 import certifi
 import defusedxml  # type: ignore[import]
-import namedthreads  # type: ignore[import]
 import tornado.httpclient
 import tornado.httputil
 import tornado.log
 import tornado.web
 import uvloop
 import yaml
+from emoji import EMOJI_DATA
+from setproctitle import setthreadtitle
 
 from .. import DIR as ROOT_DIR
 from . import braille, json  # noqa: F401  # pylint: disable=reimported
@@ -46,15 +47,22 @@ with contextlib.suppress(ImportError):
     # pylint: disable=import-error, useless-suppression
     from jxlpy import JXLImagePlugin  # type: ignore[import]  # noqa: F401
 
+_bootstrap = threading.Thread._bootstrap  # type: ignore[attr-defined]
+
+
+def _boobstrap(self: threading.Thread) -> None:
+    with contextlib.suppress(Exception):
+        setthreadtitle(self.name)
+    _bootstrap(self)
+
 
 def apply() -> None:
     """Apply the patches."""
-    if sys.flags.dev_mode:
-        namedthreads.patch()
     defusedxml.defuse_stdlib()
     defusedxml.xmlrpc.monkey_patch()
+    threading.Thread._bootstrap = _boobstrap  # type: ignore[attr-defined]
     certifi.where = lambda: os.path.join(ROOT_DIR, "ca-bundle.crt")
-    certifi.contents = lambda: Path(certifi.where()).read_text("ascii")
+    certifi.contents = lambda: Path(certifi.where()).read_text("ASCII")
     configparser.RawConfigParser.BOOLEAN_STATES.update(  # type: ignore[attr-defined]
         {
             "sure": True,
@@ -95,6 +103,51 @@ def apply() -> None:
     if not getattr(stdlib_json, "_omegajson", False):
         patch_json()
     anonymize_logs()
+    patch_emoji()
+
+
+def patch_emoji() -> None:
+    """Add cool new emoji."""
+    EMOJI_DATA["🐱\u200D💻"] = {
+        "de": ":hacker_katze:",
+        "en": ":hacker_cat:",
+        "status": 2,
+        "E": 1,
+    }
+    for de_name, en_name, rect in (
+        ("rot", "red", "🟥"),
+        ("blau", "blue", "🟦"),
+        ("orang", "orange", "🟧"),
+        ("gelb", "yellow", "🟨"),
+        ("grün", "green", "🟩"),
+        ("lilan", "purple", "🟪"),
+        ("braun", "brown", "🟫"),
+    ):
+        EMOJI_DATA[f"🫙\u200D{rect}"] = {
+            "de": f":{de_name}es_glas:",
+            "en": f":{en_name}_jar:",
+            "status": 2,
+            "E": 14,
+        }
+        EMOJI_DATA[f"🏳\uFE0F\u200D{rect}"] = {
+            "de": f":{de_name}e_flagge:",
+            "en": f":{en_name}_flag:",
+            "status": 2,
+            "E": 11,
+        }
+        EMOJI_DATA[f"\u2691\uFE0F\u200D{rect}"] = {
+            "de": f":tief{de_name}e_flagge:",
+            "en": f":deep_{en_name}_flag:",
+            "status": 2,
+            "E": 11,
+        }
+
+    # pylint: disable=import-outside-toplevel
+    import emoji.unicode_codes as euc
+
+    for lang in euc.LANGUAGES:
+        euc._EMOJI_UNICODE[lang] = None  # type: ignore[attr-defined]
+    euc._ALIASES_UNICODE.clear()  # type: ignore[attr-defined]
 
 
 def patch_json() -> None:
@@ -145,7 +198,7 @@ def ensure_bytes(value: Any) -> bytes:
         return b"true" if value else b"false"
     if isinstance(value, bytes):
         return value
-    return str(value).encode("utf-8")
+    return str(value).encode("UTF-8")
 
 
 def parse_body_arguments(  # noqa: D103, C901
