@@ -15,18 +15,14 @@
 
 from __future__ import annotations
 
-import os
 from collections.abc import Callable, Iterable
 from functools import cache
 
-from tornado.web import HTTPError, RedirectHandler
+from tornado.web import HTTPError
 
 from ..utils.request_handler import HTMLRequestHandler
-from ..utils.static_file_handling import CachedStaticFileHandler
-from ..utils.utils import ModuleInfo, PageInfo
-from . import (
+from .data import (
     ALL_SOUNDS,
-    DIR,
     MAIN_PAGE_INFO,
     PERSON_SHORTS,
     PERSON_SOUNDS,
@@ -37,77 +33,6 @@ from . import (
 )
 
 
-def get_module_info() -> ModuleInfo:
-    """Create and return the ModuleInfo for this module."""
-    return ModuleInfo(
-        name="Känguru-Soundboard",
-        short_name="Soundboard",
-        description=(
-            "Ein Soundboard mit coolen Sprüchen und Sounds aus den "
-            "Känguru-Chroniken"
-        ),
-        path="/soundboard",
-        keywords=("Soundboard", "Känguru", "Witzig", "Sprüche"),
-        handlers=(
-            (
-                r"/soundboard/files/(.*mp3)",
-                CachedStaticFileHandler,
-                {"path": os.path.join(DIR, "files")},
-            ),
-            (
-                r"/soundboard/feed",
-                SoundboardRSSHandler,
-            ),
-            (
-                r"/soundboard/feed\.(rss|xml)",
-                RedirectHandler,
-                {"url": "/soundboard/feed"},
-            ),
-            (  # redirect handler for legacy reasons
-                r"/soundboard/k(ä|%C3%A4)nguru(/.+|)",
-                RedirectHandler,
-                {"url": "/soundboard/kaenguru{1}"},
-            ),
-            (
-                r"/soundboard/([^./]+)/feed",
-                SoundboardRSSHandler,
-            ),
-            (
-                r"/soundboard/([^/]+)(\.(rss|xml)|/feed\.(rss|xml))",
-                RedirectHandler,
-                {"url": "/soundboard/{0}/feed"},
-            ),
-            (
-                r"/soundboard",
-                SoundboardHTMLHandler,
-            ),
-            (
-                r"/soundboard/([^./]+)",
-                SoundboardHTMLHandler,
-            ),
-        ),
-        sub_pages=(
-            PageInfo(
-                name="Soundboard-Suche",
-                description="Durchsuche das Soundboard",
-                path="/soundboard/suche",
-                keywords=("Suche",),
-            ),
-            PageInfo(
-                name="Soundboard-Personen",
-                description="Das Soundboard mit Sortierung nach Personen",
-                path="/soundboard/personen",
-                keywords=("Personen",),
-            ),
-        ),
-        aliases=(
-            "/kaenguru-soundboard",
-            "/känguru-soundboard",
-            "/k%C3%A4nguru-soundboard",
-        ),
-    )
-
-
 @cache
 def get_rss_str(path: str, protocol_and_host: str) -> None | str:
     """Return the RSS string for the given path."""
