@@ -15,49 +15,23 @@
 
 from __future__ import annotations
 
-import base64
 import os
 from asyncio import Future
+from base64 import b64decode, b64encode
+from dataclasses import dataclass
 
-from tornado.web import HTTPError
+from tornado.web import HTTPError, MissingArgumentError
 
-from .. import GH_ORG_URL
+from ..utils.data_parsing import parse_args
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
-from ..utils.utils import ModuleInfo, PageInfo
-from . import DIR
-from .sw_config_file import InvalidConfigError, SwappedWordsConfig
-
-
-def get_module_info() -> ModuleInfo:
-    """Create and return the ModuleInfo for this module."""
-    return ModuleInfo(
-        handlers=(
-            (r"/vertauschte-woerter", SwappedWords),
-            (r"/api/vertauschte-woerter", SwappedWordsAPI),
-        ),
-        name="Vertauschte Wörter",
-        description="Eine Seite, die Wörter vertauscht",
-        path="/vertauschte-woerter",
-        keywords=("vertauschte", "Wörter", "witzig", "Känguru"),
-        sub_pages=(
-            PageInfo(
-                name="Plugin",
-                description="Ein Browser-Plugin, welches Wörter vertauscht",
-                path=f"{GH_ORG_URL}/VertauschteWoerterPlugin",
-            ),
-        ),
-        aliases=(
-            "/swapped-words",
-            "/vertauschte-wörter",
-            "/vertauschte-w%C3%B6rter",
-        ),
-    )
+from .config_file import InvalidConfigError, SwappedWordsConfig
 
+DIR = os.path.dirname(__file__)
 
 # the max char count of the text to process
 MAX_CHAR_COUNT = 32768
 
-with open(os.path.join(DIR, "config.sw"), encoding="utf-8") as file:
+with open(os.path.join(DIR, "config.sw"), encoding="UTF-8") as file:
     DEFAULT_CONFIG: SwappedWordsConfig = SwappedWordsConfig(file.read())
 
 
@@ -76,44 +50,55 @@ def check_text_too_long(text: str) -> None:
         )
 
 
+@dataclass
+class SwArgs:
+    """Arguments used for swapped words."""
+
+    text: str = ""
+    config: None | str = None
+    reset: bool = False
+    return_config: bool = False
+    minify_config: bool = False
+
+    def validate(self) -> None:
+        """Validate the given data."""
+        self.text = self.text.strip()
+        check_text_too_long(self.text)
+        if self.config:
+            self.config = self.config.strip()
+
+    def validate_require_text(self) -> None:
+        """Validate the given data and require the text argument."""
+        self.validate()
+        if not self.text:
+            raise MissingArgumentError("text")
+
+
 class SwappedWords(HTMLRequestHandler):
     """The request handler for the swapped words page."""
 
-    async def get(
-        self, *, head: bool = False  # pylint: disable=unused-argument
-    ) -> None:
+    @parse_args(type_=SwArgs, validation_method="validate")
+    async def get(self, *, head: bool = False, args: SwArgs) -> None:
         """Handle GET requests to the swapped words page."""
-        await self.handle_text(
-            self.get_argument("text", ""),
-            self.get_argument("config", None),
-            self.get_bool_argument("reset", False),
-        )
+        # pylint: disable=unused-argument
+        await self.handle_text(args)
 
-    def handle_text(
-        self, text: str, config_str: None | str, use_default_config: bool
-    ) -> Future[None]:
+    def handle_text(self, args: SwArgs) -> Future[None]:
         """Use the text to display the HTML page."""
-        check_text_too_long(text)
-
-        if config_str is None:
+        if args.config is None:
             cookie = self.get_cookie(
                 "swapped-words-config",
                 None,
             )
             if cookie is not None:
                 # decode the base64 text
-                config_str = str(
-                    base64.b64decode(cookie.encode("utf-8")), "utf-8"
-                )
+                args.config = b64decode(cookie).decode("UTF-8")
         else:
             # save the config in a cookie
             self.set_cookie(
                 name="swapped-words-config",
-                value=str(
-                    # encode the config as base64
-                    base64.b64encode(config_str.encode("utf-8")),
-                    "utf-8",
-                ),
+                # encode the config as base64
+                value=b64encode(args.config.encode("UTF-8")).decode("UTF-8"),
                 expires_days=1000,
                 path=self.request.path,
                 SameSite="Strict",
@@ -122,36 +107,33 @@ class SwappedWords(HTMLRequestHandler):
         try:
             sw_config = (
                 DEFAULT_CONFIG
-                if config_str is None or use_default_config
-                else SwappedWordsConfig(config_str)
+                if args.config is None or args.reset
+                else SwappedWordsConfig(args.config)
             )
         except InvalidConfigError as exc:
             self.set_status(400)
             return self.render(
                 "pages/swapped_words.html",
-                text=text,
+                text=args.text,
                 output="",
-                config=config_str,
+                config=args.config,
                 MAX_CHAR_COUNT=MAX_CHAR_COUNT,
                 error_msg=str(exc),
             )
         else:  # everything went well
             return self.render(
                 "pages/swapped_words.html",
-                text=text,
-                output=sw_config.swap_words(text),
+                text=args.text,
+                output=sw_config.swap_words(args.text),
                 config=sw_config.to_config_str(),
                 MAX_CHAR_COUNT=MAX_CHAR_COUNT,
                 error_msg=None,
             )
 
-    async def post(self) -> None:
+    @parse_args(type_=SwArgs, validation_method="validate_require_text")
+    async def post(self, *, args: SwArgs) -> None:
         """Handle POST requests to the swapped words page."""
-        await self.handle_text(
-            self.get_argument("text"),
-            self.get_argument("config", None),
-            self.get_bool_argument("reset", False),
-        )
+        await self.handle_text(args)
 
 
 class SwappedWordsAPI(APIRequestHandler):
@@ -159,37 +141,29 @@ class SwappedWordsAPI(APIRequestHandler):
 
     ALLOWED_METHODS: tuple[str, ...] = ("GET", "POST")
 
-    async def get(
-        self, *, head: bool = False  # pylint: disable=unused-argument
-    ) -> None:
+    @parse_args(type_=SwArgs, validation_method="validate")
+    async def get(self, *, head: bool = False, args: SwArgs) -> None:
         """Handle GET requests to the swapped words API."""
-        text = self.get_argument("text", "")
-
-        check_text_too_long(text)
-
-        config_str = self.get_argument("config", None)
-        return_config = self.get_bool_argument("return_config", False)
+        # pylint: disable=unused-argument
         try:
             sw_config = (
                 DEFAULT_CONFIG
-                if config_str is None
-                else SwappedWordsConfig(config_str)
+                if args.config is None
+                else SwappedWordsConfig(args.config)
             )
 
-            if return_config:
-
-                minify_config = self.get_bool_argument("minify_config", True)
+            if args.return_config:
                 return await self.finish_dict(
-                    text=text,
+                    text=args.text,
                     return_config=True,
-                    minify_config=minify_config,
-                    config=sw_config.to_config_str(minify_config),
-                    replaced_text=sw_config.swap_words(text),
+                    minify_config=args.minify_config,
+                    config=sw_config.to_config_str(args.minify_config),
+                    replaced_text=sw_config.swap_words(args.text),
                 )
             return await self.finish_dict(
-                text=text,
+                text=args.text,
                 return_config=False,
-                replaced_text=sw_config.swap_words(text),
+                replaced_text=sw_config.swap_words(args.text),
             )
         except InvalidConfigError as exc:
             self.set_status(400)
@@ -201,4 +175,4 @@ class SwappedWordsAPI(APIRequestHandler):
 
     async def post(self) -> None:
         """Handle POST requests to the swapped words API."""
-        return await self.get()
+        return await self.get()  # pylint: disable=missing-kwoa
