@@ -50,7 +50,13 @@ from tornado.web import (
     RequestHandler,
 )
 
-from .. import EVENT_ELASTICSEARCH, EVENT_REDIS, NAME, ORJSON_OPTIONS
+from .. import (
+    EVENT_ELASTICSEARCH,
+    EVENT_REDIS,
+    NAME,
+    ORJSON_OPTIONS,
+    pytest_is_running,
+)
 from .static_file_handling import FILE_HASHES_DICT
 from .utils import (
     THEMES,
@@ -481,14 +487,14 @@ class BaseRequestHandler(RequestHandler):
 
     def get_user_id(self) -> str:
         """Get the user id saved in the cookie or create one."""
-        _user_id = self.get_secure_cookie(
+        cookie = self.get_secure_cookie(
             "user_id",
             max_age_days=90,
             min_version=2,
         )
-        user_id = (
-            str(uuid.uuid4()) if _user_id is None else _user_id.decode("ascii")
-        )
+
+        user_id = cookie.decode("UTF-8") if cookie else str(uuid.uuid4())
+
         # save it in cookie or reset expiry date
         if not self.get_secure_cookie(
             "user_id", max_age_days=30, min_version=2
@@ -500,6 +506,7 @@ class BaseRequestHandler(RequestHandler):
                 path="/",
                 samesite="Strict",
             )
+
         return user_id
 
     def handle_accept_header(
@@ -558,7 +565,7 @@ class BaseRequestHandler(RequestHandler):
 
         def keydecode(token: str) -> None | str:
             try:
-                return b64decode(token).decode("utf-8")
+                return b64decode(token).decode("UTF-8")
             except ValueError:
                 return None
 
@@ -636,17 +643,15 @@ class BaseRequestHandler(RequestHandler):
         self.handle_accept_header(self.POSSIBLE_CONTENT_TYPES)
 
         if self.request.method == "GET":
-
             if self.redirect_to_canonical_domain():
                 return
 
-            if not self.settings.get("TESTING") and (
+            if not pytest_is_running() and (
                 days := random.randint(0, 31337)  # nosec: B311
             ) in {69, 420, 1337, 31337}:
                 self.set_cookie("c", "s", expires_days=days / 24, path="/")
 
         if self.request.method != "OPTIONS":
-
             required_permission = self.REQUIRED_PERMISSION
             required_permission_for_method = getattr(
                 self, f"REQUIRED_PERMISSION_{self.request.method}", None
@@ -841,8 +846,9 @@ class BaseRequestHandler(RequestHandler):
             "style-src 'self' 'unsafe-inline';"
             "img-src 'self' https://img.zeit.de https://github.asozial.org;"
             "frame-ancestors 'self';"
-            "sandbox allow-downloads allow-same-origin allow-popups allow-scripts"
-            " allow-top-navigation-by-user-activation allow-forms  allow-modals;"
+            "sandbox allow-downloads allow-same-origin allow-modals"
+            " allow-popups-to-escape-sandbox allow-scripts allow-popups"
+            " allow-top-navigation-by-user-activation allow-forms;"
             "report-to default;"
             + (
                 f"report-uri {self.get_reporting_api_endpoint()};"
@@ -850,7 +856,8 @@ class BaseRequestHandler(RequestHandler):
                 else ""
             )
             + (
-                f"connect-src 'self' {self.settings['ELASTIC_APM']['SERVER_URL']};"
+                "connect-src 'self'"
+                f" {self.settings['ELASTIC_APM']['SERVER_URL']};"
                 if self.apm_enabled
                 and "SERVER_URL" in self.settings["ELASTIC_APM"]
                 else ""
@@ -957,7 +964,7 @@ class BaseRequestHandler(RequestHandler):
         if self.now.date() == date(self.now.year, 4, 27):
             if isinstance(chunk, bytes):
                 with contextlib.suppress(UnicodeDecodeError):
-                    chunk = chunk.decode("utf-8")
+                    chunk = chunk.decode("UTF-8")
             if isinstance(chunk, str):
                 chunk = regex.sub(
                     r"\b\p{Lu}\p{Ll}{4}\p{Ll}*\b",
