@@ -21,7 +21,6 @@ from __future__ import annotations
 
 import logging
 import os
-import sys
 from asyncio import Future
 from datetime import date, datetime, timedelta
 from http.client import responses
@@ -38,12 +37,11 @@ from tornado.httpclient import AsyncHTTPClient
 from tornado.web import HTTPError
 
 from .. import DIR as ROOT_DIR
-from .. import GH_ORG_URL, GH_PAGES_URL, GH_REPO_URL
+from .. import GH_ORG_URL, GH_PAGES_URL, GH_REPO_URL, pytest_is_running
 from .base_request_handler import BaseRequestHandler
 from .static_file_handling import fix_static_path
 from .utils import (
     SUS_PATHS,
-    ModuleInfo,
     Permission,
     bool_to_str,
     emoji2html,
@@ -56,28 +54,6 @@ from .utils import (
 logger = logging.getLogger(__name__)
 
 
-def get_module_info() -> ModuleInfo:
-    """Create and return the ModuleInfo for this module."""
-    return ModuleInfo(
-        name="Utilities",
-        description="Nützliche Werkzeuge für alle möglichen Sachen.",
-        handlers=(
-            (
-                r"/error",
-                ZeroDivision if sys.flags.dev_mode else NotFoundHandler,
-                {},
-            ),
-            (r"/([1-5][0-9]{2}).html?", ErrorPage, {}),
-            (
-                r"/@elastic/apm-rum@(.+)/dist/bundles"
-                r"/elastic-apm-rum.umd(\.min|).js(\.map|)",
-                ElasticRUM,
-            ),
-        ),
-        hidden=True,
-    )
-
-
 class HTMLRequestHandler(BaseRequestHandler):
     """A request handler that serves HTML."""
 
@@ -104,7 +80,7 @@ class HTMLRequestHandler(BaseRequestHandler):
         ):
             return super().finish(chunk)
 
-        chunk = chunk.decode("utf-8") if isinstance(chunk, bytes) else chunk
+        chunk = chunk.decode("UTF-8") if isinstance(chunk, bytes) else chunk
 
         if as_markdown:
             return super().finish(
@@ -182,8 +158,7 @@ class HTMLRequestHandler(BaseRequestHandler):
             ansi2html=Ansi2HTMLConverter(inline=True, scheme="xterm"),
             as_html=self.content_type == "text/html",
             bumpscosity=self.get_bumpscosity(),
-            c=self.settings.get("TESTING")
-            or self.now.date() == date(self.now.year, 4, 1)
+            c=self.now.date() == date(self.now.year, 4, 1)
             or str_to_bool(self.get_cookie("c", "f") or "f", False),
             canonical_url=self.fix_url(
                 self.request.full_url().upper()
@@ -214,6 +189,7 @@ class HTMLRequestHandler(BaseRequestHandler):
             now=self.now,
             settings=self.settings,
             short_title=self.short_title,
+            testing=pytest_is_running(),
             theme=self.get_display_theme(),
             title=self.title,
             apm_script=self.settings["ELASTIC_APM"].get("INLINE_SCRIPT")
@@ -222,11 +198,11 @@ class HTMLRequestHandler(BaseRequestHandler):
         )
         namespace.update(
             {
-                "🥚": self.settings.get("TESTING")
+                "🥚": pytest_is_running()
                 or timedelta()
                 <= self.now.date() - easter(self.now.year)
                 < timedelta(days=2),
-                "🦘": self.settings.get("TESTING")
+                "🦘": pytest_is_running()
                 or isprime(self.now.microsecond),  # type: ignore[no-untyped-call]
             }
         )
